Look in this module for documentation on building your Elevation API query. In particular, look at the Request struct for examples of the builder pattern. This module contains the tools (enums, structs, methods) for building your Google Maps Platform request.
Modules
- locations
- Contains the
Locationsenum and its associated traits. It is used to specify a series of location in the form of latitude & longitude pairs, or as an Encoded Polyline.
Structs
- Request
- Look at this
Requeststruct for documentation on how to build your Elevation API query. The methods implemented for this struct are what’s used to build your request.