Module locations

Module locations 

Contains the Locations enum and its associated traits. It is used to specify a series of location in the form of latitude & longitude pairs, or as an Encoded Polyline.

Enums

Locations
Defines the location(s) on the earth from which to return elevation data.