pub enum Locations {
LatLngs(Vec<LatLng>),
Polyline(String),
}Expand description
Defines the location(s) on the earth from which to return elevation data.
This parameter takes either a single location as a latitude/longitude pair, multiple latitude/longitude pairs, or an encoded polyline.
Variants
LatLngs(Vec<LatLng>)
A single or multiple latitude/longitude pairs.
Polyline(String)
An encoded polyline.
See also: the Google Encoded Polyline encoding & decoding crate called polyline.
Implementations
Sourceimpl Locations
impl Locations
Sourcepub fn from_polyline(polyline: impl Into<String>) -> Self
pub fn from_polyline(polyline: impl Into<String>) -> Self
An encoded polyline.
See also: the Google Encoded Polyline encoding & decoding crate called polyline.