pub enum Status {
InvalidRequest,
Ok,
OverDailyLimit,
OverQueryLimit,
RequestDenied,
UnknownError,
ZeroResults,
}Expand description
Indicates the status of the response.
Variants
InvalidRequest
Generally indicates one of the following:
- The query (
address,componentsorlatlng) is missing. - An invalid
result_typeorlocation_typewas given.
Ok
Indicates that no errors occurred; the address was successfully parsed and at least one geocode was returned.
OverDailyLimit
Indicates any of the following:
- The API key is missing or invalid.
- Billing has not been enabled on your account.
- A self-imposed usage cap has been exceeded.
- The provided method of payment is no longer valid (for example, a credit card has expired).
See the Maps FAQ to learn how to fix this.
OverQueryLimit
Indicates the requestor has exceeded quota.
RequestDenied
Indicates that the API did not complete the request. Confirm that the request was sent over HTTPS instead of HTTP.
UnknownError
Indicates that the request could not be processed due to a server error. The request may succeed if you try again.
ZeroResults
Indicates that the geocode was successful but returned no results. This
may occur if the geocoder was passed a non-existent address. This may
also occur if the geocoder was passed a latlng in a remote location.