#[repr(u8)]pub enum UnitSystem {
Imperial = 0,
Metric = 1,
}Expand description
Specifies the unit system to use when displaying results.
Directions results contain text within distance fields that may be
displayed to the user to indicate the distance of a particular “step” of the
route. By default, this text uses the unit system of the origin’s country or
region.
For example, a route from “Chicago, IL” to “Toronto, ONT” will display
results in miles, while the reverse route will display results in
kilometers. You may override this unit system by setting one explicitly
within the request’s units parameter, passing one of the following values:
Note: this unit system setting only affects the text displayed within
distance fields. The distance fields also contain values which are
always expressed in meters.
Variants
Imperial = 0
Specifies that distances in the response should be expressed in imperial units, miles and feet.
Metric = 1
Specifies that distances in the response should be expressed in metric units, using kilometres and metres.
Implementations